@@ -92,15 +92,11 @@ def die_unless_hint_nonpep(
     # subsequent logic raises an exception specific to the passed parameters.
     #
     # Note that the prior call has already validated "is_str_valid".
-    assert isinstance(hint_label, str), (
-        f'{repr(hint_label)} not string.')
-    assert isinstance(exception_cls, type), (
-        f'{repr(exception_cls)} not type.')
+    assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
+    assert isinstance(exception_cls, type), f'{repr(exception_cls)} not type.'
 
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # BEGIN: Synchronize changes here with both:
-    # * The is_hint_nonpep() tester defined below.
-    # * Tuple iteration performed below.
+    # BEGIN: Synchronize changes here with the is_hint_nonpep() tester below.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Avoid circular import dependencies.
@@ -120,53 +116,14 @@ def die_unless_hint_nonpep(
         return
     # Else, this object is *NOT* a class.
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # END: Synchronize changes above with tuple iteration performed below.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-
-    # If this object is a tuple...
+    # If this object is a tuple, raise a tuple-specific exception.
     if isinstance(hint, tuple):
-        # If this tuple is empty, raise an exception.
-        if not hint:
-            raise exception_cls(f'{hint_label} tuple empty.')
-        # Else, this tuple is non-empty.
-
-        # For each item of this tuple...
-        for hint_item in hint:
-            # Duplicate the above logic. For negligible efficiency gains (and
-            # more importantly to avoid exhausting the stack), avoid calling
-            # this function recursively to do so. *shrug*
-
-            # If this item is a class...
-            if isinstance(hint_item, type):
-                # If this is a PEP-compliant class, raise an exception.
-                die_if_hint_pep(
-                    hint=hint_item,
-                    hint_label=hint_label,
-                    exception_cls=exception_cls,
-                )
-                # Else, this is a PEP-noncompliant class. In this case,
-                # silently accept this class as is.
-            # Else, this item is *NOT* a class.
-            #
-            # If this item is a forward reference...
-            elif isinstance(hint_item, str):
-                # If forward references are unsupported, raise an exception.
-                if not is_str_valid:
-                    raise exception_cls(
-                        f'{hint_label} {repr(hint)} '
-                        f'forward reference "{hint_item}" unsupported.'
-                    )
-                # Else, silently accept this item.
-            # Else, this item is neither a class nor forward reference. Ergo,
-            # this item is *NOT* a PEP-noncompliant type hint. In this case,
-            # raise an exception whose message contextually depends on whether
-            # forward references are permitted or not.
-            else:
-                raise exception_cls(
-                    f'{hint_label} {repr(hint)} item {repr(hint_item)} '
-                    f'{"neither type nor string" if is_str_valid else "not type"}.'
-                )
+        die_unless_hint_nonpep_tuple(
+            hint=hint,
+            hint_label=hint_label,
+            is_str_valid=is_str_valid,
+            exception_cls=exception_cls,
+        )
 
     # Else, this object is neither a forward reference, class, nor tuple. Ergo,
     # this object is *NOT* a PEP-noncompliant type hint.
@@ -183,8 +140,133 @@ def die_unless_hint_nonpep(
         raise exception_cls(
             f'{hint_label} {repr(hint)} neither type nor tuple of types.')
 
+
+def die_unless_hint_nonpep_tuple(
+    # Mandatory parameters.
+    hint: object,
+
+    # Optional parameters.
+    hint_label: str = 'Type hint',
+    is_str_valid: bool = True,
+    exception_cls: type = BeartypeDecorHintNonPepException,
+) -> None:
+    '''
+    Raise an exception unless the passed object is a **PEP-noncompliant type
+    hint** (i.e., :mod:`beartype`-specific annotation *not* compliant with
+    annotation-centric PEPs).
+
+    This validator is effectively (but technically *not*) memoized. See the
+    :func:`beartype._util.hint.utilhinttest.die_unless_hint` validator.
+
+    Parameters
+    ----------
+    hint : object
+        Object to be validated.
+    hint_label : Optional[str]
+        Human-readable label prefixing this object's representation in the
+        exception message raised by this function. Defaults to ``Type hint``.
+    is_str_valid : Optional[bool]
+        ``True`` only if this function permits this object to be a string.
+        Defaults to ``True``. If this boolean is:
+
+        * ``True``, this object is valid only if this object is either a class
+          or tuple of classes and/or classnames.
+        * ``False``, this object is valid only if this object is either a class
+          or tuple of classes.
+    exception_cls : Optional[type]
+        Type of the exception to be raised by this function. Defaults to
+        :class:`BeartypeDecorHintNonPepException`.
+
+    Raises
+    ----------
+    TypeError
+        If this object is **unhashable** (i.e., *not* hashable by the builtin
+        :func:`hash` function and thus unusable in hash-based containers like
+        dictionaries and sets). All supported type hints are hashable.
+    exception_type
+        If this object is neither:
+
+        * A non-:mod:`typing` type (i.e., class *not* defined by the
+          :mod:`typing` module, whose public classes are used to instantiate
+          PEP-compliant type hints or objects satisfying such hints that
+          typically violate standard class semantics and thus require
+          PEP-specific handling).
+        * A **non-empty tuple** (i.e., semantic union of types) containing one
+          or more:
+
+          * Non-:mod:`typing` types.
+          * If ``is_str_valid``, **strings** (i.e., forward references
+            specified as either fully-qualified or unqualified classnames).
+    '''
+
+    # If this object is a PEP-noncompliant tuple, reduce to a noop.
+    #
+    # Note that this memoized call is intentionally passed positional rather
+    # than keyword parameters to maximize efficiency.
+    if is_hint_nonpep_tuple(hint, is_str_valid):
+        return
+    # Else, this object is *NOT* a PEP-noncompliant tuple. In this case,
+    # subsequent logic raises an exception specific to the passed parameters.
+    #
+    # Note that the prior call has already validated "is_str_valid".
+    assert isinstance(hint_label, str), f'{repr(hint_label)} not string.'
+    assert isinstance(exception_cls, type), f'{repr(exception_cls)} not type.'
+
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    # BEGIN: Synchronize changes here with the is_hint_nonpep_tuple() tester.
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.utilhintpeptest import die_if_hint_pep
+
+    # If this object is *NOT* a tuple, raise an exception.
+    if not isinstance(hint, tuple):
+        raise exception_cls(f'{hint_label} {repr(hint)} not tuple.')
+    # Else, this object is a tuple.
+    #
+    # If this tuple is empty, raise an exception.
+    elif not hint:
+        raise exception_cls(f'{hint_label} tuple empty.')
+    # Else, this tuple is non-empty.
+
+    # For each item of this tuple...
+    for hint_item in hint:
+        # Duplicate the above logic. For negligible efficiency gains (and
+        # more importantly to avoid exhausting the stack), avoid calling
+        # this function recursively to do so. *shrug*
+
+        # If this item is a class...
+        if isinstance(hint_item, type):
+            # If this is a PEP-compliant class, raise an exception.
+            die_if_hint_pep(
+                hint=hint_item,
+                hint_label=hint_label,
+                exception_cls=exception_cls,
+            )
+            # Else, this is a PEP-noncompliant class. In this case,
+            # silently accept this class as is.
+        # Else, this item is *NOT* a class.
+        #
+        # If this item is a forward reference...
+        elif isinstance(hint_item, str):
+            # If forward references are unsupported, raise an exception.
+            if not is_str_valid:
+                raise exception_cls(
+                    f'{hint_label} {repr(hint)} '
+                    f'forward reference "{hint_item}" unsupported.'
+                )
+            # Else, silently accept this item.
+        # Else, this item is neither a class nor forward reference. Ergo,
+        # this item is *NOT* a PEP-noncompliant type hint. In this case,
+        # raise an exception whose message contextually depends on whether
+        # forward references are permitted or not.
+        else:
+            raise exception_cls(
+                f'{hint_label} {repr(hint)} item {repr(hint_item)} '
+                f'{"neither type nor string" if is_str_valid else "not type"}.'
+            )
+
 # ....................{ TESTERS                           }....................
-@callable_cached
 def is_hint_nonpep(
     # Mandatory parameters.
     hint: object,
@@ -197,7 +279,9 @@ def is_hint_nonpep(
     (i.e., :mod:`beartype`-specific annotation *not* compliant with
     annotation-centric PEPs).
 
-    This tester is memoized for efficiency.
+    This tester is intentionally *not* memoized (e.g., by the
+    :func:`callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
 
     Parameters
     ----------
@@ -228,13 +312,6 @@ def is_hint_nonpep(
           * Non-:mod:`typing` types.
           * If ``is_str_valid``, **strings** (i.e., forward references
             specified as either fully-qualified or unqualified classnames).
-
-    Raises
-    ----------
-    TypeError
-        If this object is **unhashable** (i.e., *not* hashable by the builtin
-        :func:`hash` function and thus unusable in hash-based containers like
-        dictionaries and sets). All supported type hints are hashable.
     '''
     assert isinstance(is_str_valid, bool), f'{repr(is_str_valid)} not boolean.'
 
@@ -251,19 +328,76 @@ def is_hint_nonpep(
         # PEP-compliant class, in which case this *MUST* be a PEP-noncompliant
         # class by definition.
         not is_hint_pep(hint) if isinstance(hint, type) else
-        # Else, this object is neither a class nor forward reference.
+        # Else, this object is *NOT* a class.
         #
-        # If this object is a non-empty tuple, return true only if each item of
-        # this tuple is either a caller-permitted forward reference *OR* a
-        # PEP-noncompliant class.
+        # If this object is a tuple, return true only if this tuple contains
+        # only one or more caller-permitted forward references and
+        # PEP-noncompliant classes.
+        is_hint_nonpep_tuple(hint, is_str_valid) if isinstance(hint, tuple)
+        # Else, this object is neither a class nor tuple. Return false, as this
+        # object *CANNOT* be PEP-noncompliant.
+        else False
+    )
+
+
+@callable_cached
+def is_hint_nonpep_tuple(
+    # Mandatory parameters.
+    hint: object,
+
+    # Optional parameters.
+    is_str_valid: bool = True,
+) -> bool:
+    '''
+    ``True`` only if the passed object is a PEP-noncompliant non-empty tuple of
+    one or more classes.
+
+    This tester is memoized for efficiency.
+
+    Parameters
+    ----------
+    hint : object
+        Object to be inspected.
+    is_str_valid : Optional[bool]
+        ``True`` only if this function permits this object to be a string.
+        Defaults to ``True``. If this boolean is:
+
+        * ``True``, this object is valid only if this object is a tuple of
+          classes and/or classnames.
+        * ``False``, this object is valid only if this object is a tuple of
+          classes.
+
+    Returns
+    ----------
+    bool
+        ``True`` only if this object is a **non-empty tuple** (i.e., semantic
+        union of types) containing one or more:
+
+          * Non-:mod:`typing` types.
+          * If ``is_str_valid``, **strings** (i.e., forward references
+            specified as either fully-qualified or unqualified classnames).
+    '''
+    assert isinstance(is_str_valid, bool), f'{repr(is_str_valid)} not boolean.'
+
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    # BEGIN: Synchronize changes here with die_unless_hint_nonpep() above.
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.utilhintpeptest import is_hint_pep
+
+    # Return true only if this object is...
+    return (
+        # A tuple *AND*...
+        isinstance(hint, tuple) and
+        # This tuple is non-empty *AND*...
+        len(hint) > 0 and
+        # Each item of this tuple is either a caller-permitted forward
+        # reference *OR* a PEP-noncompliant class.
         all(
             not is_hint_pep(hint_item) if isinstance(hint_item, type) else
             is_str_valid               if isinstance(hint_item, str) else
             False
             for hint_item in hint
-        ) if (isinstance(hint, tuple) and hint) else
-        # Else, this object is neither a forward reference, class, nor
-        # non-empty tuple. Return false, as this object is *NOT* a
-        # PEP-noncompliant type hint.
-        False
+        )
     )
