@@ -6,6 +6,24 @@
 '''
 **Beartype** `PEP 484`_**-compliant type hint test data.**
 
+Caveats
+----------
+Note that:
+
+* The `PEP 484`_-compliant annotated builtin containers created and returned by
+  the :func:`typing.NamedTuple` and :func:`typing.TypedDict` factory functions
+  are *mostly* indistinguishable from PEP-noncompliant types and thus
+  intentionally tested in the
+  :mod:`beartype_test.unit.data.hint.pep.proposal._data_hintpep544` submodule
+  rather than here despite being specified by `PEP 484`_.
+* The ``typing.Supports*`` family of abstract base classes (ABCs) are
+  intentionally tested in the
+  :mod:`beartype_test.unit.data.hint.pep.proposal._data_hintpep544` submodule
+  rather than here despite being specified by `PEP 484`_ and available under
+  Python < 3.8. Why? Because the implementation of these ABCs under Python <
+  3.8 is unusable at runtime, which is nonsensical and awful, but that's
+  :mod:`typing` for you. What you goin' do?
+
 .. _PEP 484:
     https://www.python.org/dev/peps/pep-0484
 '''
@@ -16,24 +34,19 @@ from beartype.cave import (
     RegexMatchType,
     RegexCompiledType,
 )
+from beartype._util.hint.data.pep.proposal.utilhintdatapep484 import (
+    HINT_PEP484_BASE_FORWARDREF)
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_7,
     IS_PYTHON_AT_LEAST_3_9,
 )
-from beartype_test.unit.data.hint.pep.data_hintpepmeta import (
+from beartype_test.unit.data.hint.data_hintmeta import (
     PepHintMetadata,
-    PepHintNonsignedMetadata,
     PepHintPithSatisfiedMetadata,
     PepHintPithUnsatisfiedMetadata,
 )
 from collections import abc as collections_abc
 from contextlib import contextmanager
-
-# Note that the "typing.Supports*" family of abstract base classes (ABCs) are
-# intentionally tested in the "_data_hintpep544" submodule rather than here
-# despite being specified by PEP 484 and available under Python < 3.8.0. Why?
-# Because the implementation of these ABCs under Python < 3.8.0 is unusable at
-# runtime, which is nonsensical and awful, but that's "typing" for you.
 from typing import (
     Any,
     AnyStr,
@@ -49,7 +62,6 @@ from typing import (
     List,
     Match,
     MutableSequence,
-    NamedTuple,
     NewType,
     Pattern,
     Sequence,
@@ -239,14 +251,6 @@ def _make_generator_yield_int_send_float_return_str() -> (
     # Return a string constant.
     return 'Unmarred, scarred revanent remnants'
 
-# ....................{ COLLECTIONS                       }....................
-NamedTupleType = NamedTuple(
-    'NamedTupleType', [('fumarole', str), ('enrolled', int)])
-'''
-PEP-compliant user-defined :func:`collections.namedtuple` instance typed with
-PEP-compliant annotations.
-'''
-
 # ....................{ ADDERS                            }....................
 def add_data(data_module: 'ModuleType') -> None:
     '''
@@ -273,23 +277,64 @@ def add_data(data_module: 'ModuleType') -> None:
     # unparametrized by default.
     _IS_SIGN_TYPEVARED = not IS_PYTHON_AT_LEAST_3_9
 
+    # ..................{ SETS                              }..................
+    # Add PEP 484-specific deeply ignorable test type hints to that set global.
+    data_module.HINTS_PEP_IGNORABLE_DEEP.update((
+        # Parametrizations of the "typing.Generic" abstract base class (ABC).
+        Generic[S, T],
+
+        # New type aliasing an ignorable type.
+        NewType('TotallyNotAnObjeect', object),
+
+        # Optionals containing any ignorable type hint.
+        Optional[Any],
+        Optional[object],
+
+        # Unions containing any ignorable type hint.
+        Union[Any, float, str,],
+        Union[complex, int, object,],
+    ))
+
+    # Add PEP 484-specific invalid non-generic classes to that set global.
+    data_module.HINTS_PEP_INVALID_CLASS_NONGENERIC.update((
+        # The "TypeVar" class as is does *NOT* constitute a valid type hint.
+        TypeVar,
+
+        # The "ForwardRef" class as is does *NOT* constitute a valid type hint.
+        HINT_PEP484_BASE_FORWARDREF,
+    ))
+
+    # ..................{ TUPLES                            }..................
     # Add PEP 484-specific test type hints to this dictionary global.
-    data_module.HINT_PEP_TO_META.update({
+    data_module.HINTS_PEP_META.extend((
         # ................{ UNSUBSCRIPTED                     }................
         # Note that the PEP 484-compliant unsubscripted "NoReturn" type hint is
         # permissible *ONLY* as a return annotation and *MUST* thus be
         # exercised independently with special-purposed unit tests.
-        Any: PepHintMetadata(
+        PepHintMetadata(
+            hint=Any,
             pep_sign=Any,
             is_ignorable=True,
         ),
-        ByteString: PepHintMetadata(
+
+        # Unsubscripted "ByteString" singleton. Bizarrely, note that:
+        # * "collections.abc.ByteString" is subscriptable under PEP 585.
+        # * "typing.ByteString" is *NOT* subscriptable under PEP 484.
+        #
+        # Since neither PEP 484 nor 585 comment on "ByteString" in detail (or
+        # at all, really), this non-orthogonality remains inexplicable,
+        # frustrating, and utterly unsurprising.
+        PepHintMetadata(
+            hint=ByteString,
             pep_sign=ByteString,
             type_origin=collections_abc.ByteString,
             piths_satisfied_meta=(
                 # Byte string constant.
                 PepHintPithSatisfiedMetadata(
                     b'By nautical/particle consciousness'),
+                # Byte array initialized from a byte string constant.
+                PepHintPithSatisfiedMetadata(
+                    bytearray(b"Hour's straight fates, (distemperate-ly)")),
             ),
             piths_unsatisfied_meta=(
                 # String constant.
@@ -300,7 +345,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ UNSUBSCRIPTED ~ typevar           }................
         # Generic type variable.
-        T: PepHintMetadata(
+        PepHintMetadata(
+            hint=T,
             pep_sign=TypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
@@ -315,7 +361,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # String type variable.
-        AnyStr: PepHintMetadata(
+        PepHintMetadata(
+            hint=AnyStr,
             pep_sign=TypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
@@ -338,7 +385,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ CALLABLE                          }................
-        Callable[[], str]: PepHintMetadata(
+        # Callable accepting no parameters and returning a string.
+        PepHintMetadata(
+            hint=Callable[[], str],
             pep_sign=Callable,
             type_origin=collections_abc.Callable,
             piths_satisfied_meta=(
@@ -352,7 +401,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ CONTEXTMANAGER                    }................
-        ContextManager[str]: PepHintMetadata(
+        # Context manager yielding strings.
+        PepHintMetadata(
+            hint=ContextManager[str],
             pep_sign=ContextManager,
             type_origin=contextlib.AbstractContextManager,
             piths_satisfied_meta=(
@@ -372,7 +423,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ DICT                              }................
         # Unsubscripted "Dict" attribute.
-        Dict: PepHintMetadata(
+        PepHintMetadata(
+            hint=Dict,
             pep_sign=Dict,
             is_typevared=_IS_SIGN_TYPEVARED,
             type_origin=dict,
@@ -393,7 +445,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Flat dictionary.
-        Dict[int, str]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Dict[int, str],
             pep_sign=Dict,
             type_origin=dict,
             piths_satisfied_meta=(
@@ -411,7 +464,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic dictionary.
-        Dict[S, T]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Dict[S, T],
             pep_sign=Dict,
             is_typevared=True,
             type_origin=dict,
@@ -430,7 +484,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ GENERATOR                         }................
         # Flat generator.
-        Generator[int, float, str]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Generator[int, float, str],
             pep_sign=Generator,
             type_origin=collections_abc.Generator,
             piths_satisfied_meta=(
@@ -447,7 +502,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ GENERICS ~ user                   }................
         # Generic subclassing a single unparametrized "typing" type.
-        Pep484GenericUntypevaredSingle: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pep484GenericUntypevaredSingle,
             pep_sign=Generic,
             is_typing=False,
             piths_satisfied_meta=(
@@ -470,7 +526,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic subclassing a single parametrized "typing" type.
-        Pep484GenericTypevaredSingle: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pep484GenericTypevaredSingle,
             pep_sign=Generic,
             is_typevared=True,
             is_typing=False,
@@ -489,7 +546,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Generic subclassing multiple unparametrized "typing" types *AND* a
         # non-"typing" abstract base class (ABC).
-        Pep484GenericUntypevaredMultiple: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pep484GenericUntypevaredMultiple,
             pep_sign=Generic,
             is_typing=False,
             piths_satisfied_meta=(
@@ -511,7 +569,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic subclassing multiple parametrized "typing" types.
-        Pep484GenericTypevaredShallowMultiple: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pep484GenericTypevaredShallowMultiple,
             pep_sign=Generic,
             is_typevared=True,
             is_typing=False,
@@ -532,7 +591,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Generic subclassing multiple indirectly parametrized "typing" types
         # *AND* a non-"typing" abstract base class (ABC).
-        Pep484GenericTypevaredDeepMultiple: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pep484GenericTypevaredDeepMultiple,
             pep_sign=Generic,
             is_typevared=True,
             is_typing=False,
@@ -558,9 +618,9 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # Nested list of generics subclassing multiple unparametrized "typing"
-        # types *AND* a non-"typing" abstract base class (ABC).
-        List[Pep484GenericUntypevaredMultiple]: PepHintMetadata(
+        # Nested list of PEP 484-compliant generics.
+        PepHintMetadata(
+            hint=List[Pep484GenericUntypevaredMultiple],
             pep_sign=List,
             type_origin=list,
             piths_satisfied_meta=(
@@ -593,7 +653,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ LIST                              }................
         # Unsubscripted "List" attribute.
-        List: PepHintMetadata(
+        PepHintMetadata(
+            hint=List,
             pep_sign=List,
             is_typevared=_IS_SIGN_TYPEVARED,
             type_origin=list,
@@ -620,7 +681,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # List of ignorable objects.
-        List[object]: PepHintMetadata(
+        PepHintMetadata(
+            hint=List[object],
             pep_sign=List,
             type_origin=list,
             piths_satisfied_meta=(
@@ -641,7 +703,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # List of non-"typing" objects.
-        List[str]: PepHintMetadata(
+        PepHintMetadata(
+            hint=List[str],
             pep_sign=List,
             type_origin=list,
             piths_satisfied_meta=(
@@ -673,7 +736,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic list.
-        List[T]: PepHintMetadata(
+        PepHintMetadata(
+            hint=List[T],
             pep_sign=List,
             is_typevared=True,
             type_origin=list,
@@ -695,7 +759,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ NEWTYPE                           }................
         # New type aliasing a non-ignorable type.
-        NewType('TotallyNotAStr', str): PepHintMetadata(
+        PepHintMetadata(
+            hint=NewType('TotallyNotAStr', str),
             pep_sign=NewType,
             # New types are merely pure-Python functions of the standard
             # pure-Python function type, which is *NOT* defined by the "typing"
@@ -717,7 +782,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ REGEX ~ match                     }................
         # Regular expression match of either strings or byte strings.
-        Match: PepHintMetadata(
+        PepHintMetadata(
+            hint=Match,
             pep_sign=Match,
             type_origin=RegexMatchType,
             is_typevared=_IS_SIGN_TYPEVARED,
@@ -736,7 +802,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Regular expression match of only strings.
-        Match[str]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Match[str],
             pep_sign=Match,
             type_origin=RegexMatchType,
             piths_satisfied_meta=(
@@ -754,7 +821,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ REGEX ~ pattern                   }................
         # Regular expression pattern of either strings or byte strings.
-        Pattern: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pattern,
             pep_sign=Pattern,
             type_origin=RegexCompiledType,
             is_typevared=_IS_SIGN_TYPEVARED,
@@ -770,7 +838,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Regular expression pattern of only strings.
-        Pattern[str]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Pattern[str],
             pep_sign=Pattern,
             type_origin=RegexCompiledType,
             piths_satisfied_meta=(
@@ -789,7 +858,8 @@ def add_data(data_module: 'ModuleType') -> None:
         # parametrized by one or more type variables under any Python version,
         # unlike most other unsubscripted "typing" attributes originating from
         # container types. Non-orthogonality, thy name is the "typing" module.
-        Tuple: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple,
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -817,7 +887,8 @@ def add_data(data_module: 'ModuleType') -> None:
         #     TypeError: Too few parameters for List; actual 0, expected 1
         #     >>> List[[]]
         #     TypeError: Parameters to generic types must be types. Got [].
-        Tuple[()]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[()],
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -841,7 +912,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Fixed-length tuple of only ignorable child hints.
-        Tuple[Any, object,]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[Any, object,],
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -865,7 +937,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Fixed-length tuple of at least one ignorable child hint.
-        Tuple[float, Any, str,]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[float, Any, str,],
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -913,7 +986,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Nested fixed-length tuple of at least one ignorable child hint.
-        Tuple[Tuple[float, Any, str,], ...]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[Tuple[float, Any, str,], ...],
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -962,7 +1036,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic fixed-length tuple.
-        Tuple[S, T]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[S, T],
             pep_sign=Tuple,
             is_typevared=True,
             type_origin=tuple,
@@ -986,7 +1061,8 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ TUPLE ~ variadic                  }................
         # Variadic tuple.
-        Tuple[str, ...]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[str, ...],
             pep_sign=Tuple,
             type_origin=tuple,
             piths_satisfied_meta=(
@@ -1018,7 +1094,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic variadic tuple.
-        Tuple[T, ...]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Tuple[T, ...],
             pep_sign=Tuple,
             is_typevared=True,
             type_origin=tuple,
@@ -1037,7 +1114,9 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ TYPE                              }................
-        Type: PepHintMetadata(
+        # Unsubscripted "Type" singleton.
+        PepHintMetadata(
+            hint=Type,
             pep_sign=Type,
             is_typevared=_IS_SIGN_TYPEVARED,
             type_origin=type,
@@ -1054,7 +1133,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Builtin type.
-        Type[dict]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Type[dict],
             pep_sign=Type,
             type_origin=type,
             piths_satisfied_meta=(
@@ -1068,7 +1148,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Generic type.
-        Type[T]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Type[T],
             pep_sign=Type,
             is_typevared=True,
             type_origin=type,
@@ -1083,9 +1164,11 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # ................{ UNION                             }................
-        # Note that unions of one arguments (e.g., "Union[str]") *CANNOT* be
-        # listed here, as the "typing" module implicitly reduces these unions to
-        # only that argument (e.g., "str") on our behalf. Thanks. Thanks alot.
+        # Note that unions of one argument (e.g., "Union[str]") *CANNOT* be
+        # listed here, as the "typing" module implicitly reduces these unions
+        # to only that argument (e.g., "str") on our behalf.
+        #
+        # Thanks. Thanks alot, "typing".
         #
         # !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         # CAUTION: The Python < 3.7.0-specific implementations of "Union"
@@ -1100,7 +1183,8 @@ def add_data(data_module: 'ModuleType') -> None:
         # !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
         # Ignorable unsubscripted "Union" attribute.
-        Union: PepHintMetadata(
+        PepHintMetadata(
+            hint=Union,
             pep_sign=Union,
             is_ignorable=True,
         ),
@@ -1109,7 +1193,8 @@ def add_data(data_module: 'ModuleType') -> None:
         # exercising a prominent edge case when raising human-readable
         # exceptions describing the failure of passed parameters or returned
         # values to satisfy this union.
-        Union[int, Sequence[str]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Union[int, Sequence[str]],
             pep_sign=Union,
             piths_satisfied_meta=(
                 # Integer constant.
@@ -1164,9 +1249,9 @@ def add_data(data_module: 'ModuleType') -> None:
         # exercising a prominent edge case when raising human-readable
         # exceptions describing the failure of passed parameters or returned
         # values to satisfy this union.
-        Union[dict, float, int, Sequence[
-            Union[dict, float, int, MutableSequence[
-            str]]]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Union[dict, float, int,
+                Sequence[Union[dict, float, int, MutableSequence[str]]]],
             pep_sign=Union,
             piths_satisfied_meta=(
                 # Empty dictionary.
@@ -1252,7 +1337,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Union of one non-"typing" type and one concrete generic.
-        Union[str, Iterable[Tuple[S, T]]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Union[str, Iterable[Tuple[S, T]]],
             pep_sign=Union,
             is_typevared=True,
         ),
@@ -1262,7 +1348,8 @@ def add_data(data_module: 'ModuleType') -> None:
         # optimizations leveraging PEP 572-style assignment expressions.
 
         # Nested union of multiple non-"typing" types.
-        List[Union[int, str,]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=List[Union[int, str,]],
             pep_sign=List,
             type_origin=list,
             piths_satisfied_meta=(
@@ -1310,7 +1397,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Nested union of one non-"typing" type and one "typing" type.
-        Sequence[Union[str, ByteString]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Sequence[Union[str, ByteString]],
             pep_sign=Sequence,
             type_origin=collections_abc.Sequence,
             piths_satisfied_meta=(
@@ -1356,7 +1444,8 @@ def add_data(data_module: 'ModuleType') -> None:
         ),
 
         # Nested union of no non-"typing" type and multiple "typing" types.
-        MutableSequence[Union[ByteString, Callable]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=MutableSequence[Union[ByteString, Callable]],
             pep_sign=MutableSequence,
             type_origin=collections_abc.MutableSequence,
             piths_satisfied_meta=(
@@ -1405,13 +1494,15 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # ................{ UNION ~ optional                  }................
         # Ignorable unsubscripted "Optional" attribute.
-        Optional: PepHintMetadata(
+        PepHintMetadata(
+            hint=Optional,
             pep_sign=Optional,
             is_ignorable=True,
         ),
 
         # Optional isinstance()-able "typing" type.
-        Optional[Sequence[str]]: PepHintMetadata(
+        PepHintMetadata(
+            hint=Optional[Sequence[str]],
             # Subscriptions of the "Optional" attribute reduce to
             # fundamentally different unsubscripted typing attributes depending
             # on Python version. Specifically, under:
@@ -1455,20 +1546,20 @@ def add_data(data_module: 'ModuleType') -> None:
                 ),
             ),
         ),
-    })
+    ))
 
-    # ..................{ MAPPINGS ~ update                 }..................
     # PEP-compliant type hints conditionally dependent on the major version of
     # Python targeted by the active Python interpreter.
     if IS_PYTHON_AT_LEAST_3_7:
-        data_module.HINT_PEP_TO_META.update({
+        data_module.HINTS_PEP_META.extend((
             # ..............{ UNSUBSCRIPTED                     }..............
             # See the
             # "beartype._util.hint.data.pep.utilhintdatapep.TYPING_ATTR_TO_TYPE_ORIGIN"
             # dictionary for detailed discussion.
 
             # Unsubscripted "Hashable" attribute.
-            typing.Hashable: PepHintMetadata(
+            PepHintMetadata(
+                hint=typing.Hashable,
                 pep_sign=Hashable,
                 piths_satisfied_meta=(
                     # String constant.
@@ -1491,7 +1582,8 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
 
             # Unsubscripted "Sized" attribute.
-            typing.Sized: PepHintMetadata(
+            PepHintMetadata(
+                hint=typing.Sized,
                 pep_sign=Sized,
                 piths_satisfied_meta=(
                     # String constant.
@@ -1508,55 +1600,4 @@ def add_data(data_module: 'ModuleType') -> None:
                 ),
                 type_origin=collections_abc.Sized,
             ),
-        })
-
-    data_module.HINT_PEP_CLASSED_TO_META.update({
-        # ................{ NAMEDTUPLE                        }................
-        # "NamedTuple" instances transparently reduce to standard tuples and
-        # *MUST* thus be handled as non-"typing" type hints.
-        NamedTupleType: PepHintNonsignedMetadata(
-            piths_satisfied_meta=(
-                # Named tuple containing correctly typed items.
-                PepHintPithSatisfiedMetadata(
-                    NamedTupleType(fumarole='Leviathan', enrolled=37)),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant.
-                PepHintPithUnsatisfiedMetadata('Of ͼarthen concordance that'),
-
-                #FIXME: Uncomment after implementing "NamedTuple" support.
-                # # Named tuple containing incorrectly typed items.
-                # PepHintPithUnsatisfiedMetadata(
-                #     pith=NamedTupleType(fumarole='Leviathan', enrolled=37),
-                #     # Match that the exception message raised for this object...
-                #     exception_str_match_regexes=(
-                #         # Declares the name of this tuple's problematic item.
-                #         r'\s[Ll]ist item 0\s',
-                #     ),
-                # ),
-            ),
-            type_origin=tuple,
-        ),
-
-        # ................{ COLLECTIONS ~ typeddict           }................
-        # "TypedDict" instances transparently reduce to dicts.
-        #FIXME: Implement us up, but note when doing so that "TypeDict" was first
-        #introduced with Python 3.8.
-    })
-
-    # Add PEP 484-specific deeply ignorable test type hints to that set global.
-    data_module.HINTS_PEP_IGNORABLE_DEEP.update((
-        # Parametrizations of the "typing.Generic" abstract base class (ABC).
-        Generic[S, T],
-
-        # New type aliasing an ignorable type.
-        NewType('TotallyNotAnObjeect', object),
-
-        # Optionals containing any ignorable type hint.
-        Optional[Any],
-        Optional[object],
-
-        # Unions containing any ignorable type hint.
-        Union[Any, float, str,],
-        Union[complex, int, object,],
-    ))
+        ))
